program hexagon;
const
  MAXNUMLEN = 16384;
type
  BigNum = Array[0..MAXNUMLEN-1] of Byte;

var
  p1, p2 : Longint;
  c11, c12, c21, c22 : Longint;
  cd1, cd2, cd3, tmp : Longint;

procedure get_coord(pos : Longint; var c1, c2 : Longint);
var
  rnd : Longint;
begin
  if pos = 1 then begin
    c1 := 0;
    c2 := 0;
    Exit;
  end;
  Dec(pos);
  rnd := round(int((sqrt(12*pos-3)-3)/6));
  pos := pos - (3*rnd*(rnd+1)+1);
  if pos >= 5*(rnd+1) then begin
    c1 := rnd+1;
    c2 := pos-(6*(rnd+1)-1);
  end
  else if pos >= 4*(rnd+1) then begin
    c2 := -(rnd+1);
    c1 := pos-(4*(rnd+1))+1;
  end
  else if pos >= 3*(rnd+1) then begin
    c2 := 3*(rnd+1)-pos-1;
    c1 := pos-(4*(rnd+1)-1);
  end
  else if pos >= 2*(rnd+1) then begin
    c1 := -(rnd+1);
    c2 := 3*(rnd+1)-1-pos;
  end
  else if pos >= rnd+1 then begin
    c2 := rnd+1;
    c1 := -(pos-rnd);
  end
  else begin
    c2 := pos+1;
    c1 := -(pos-rnd);
  end;
end;

procedure BigShl(var a,b : BigNum; c : Longint);
var
  i : Longint;
begin
  for i := 0 to c-1 do
    b[i] := 0;
  for i := 0 to MAXNUMLEN-1-c do
    b[i+c] := a[i];
end;

procedure BigBitShl(var a,b : BigNum);
var
  i : Longint;
begin
  b[0] := a[0] shl 1;
  for i := 1 to MAXNUMLEN-1 do
    b[i] := (a[i] shl 1) or ((a[i-1] and 128) shr 7);
end;

procedure BigInit(var a : BigNum);
var
  i : Longint;
begin
  for i := 0 to MAXNUMLEN-1 do
    a[i] := 0;
end;

procedure BigMove(var src, dest : BigNum);
var
  i : Longint;
begin
  for i := 0 to MAXNUMLEN-1 do
    dest[i] := src[i];
end;

procedure BigAdd(var res, a : BigNum);
var
  tmp, i : Longint;
  carry : Integer;
begin
  carry := 0;
  for i := 0 to MAXNUMLEN-1 do begin
    tmp := Longint(res[i])+Longint(a[i])+carry;
    res[i] := tmp and 255;
    carry := tmp shr 8;
  end;
end;

procedure BigSub(var res, s : BigNum);
var
  tmp, i : Longint;
  carry : Integer;
begin
  carry := 0;
  for i := 0 to MAXNUMLEN-1 do begin
    tmp := Longint(res[i])-Longint(s[i])-carry;
    if tmp < 0 then begin
      carry := 1;
      res[i] := tmp+256;
    end
    else begin
      carry := 0;
      res[i] := tmp;
    end;
  end;
end;

procedure BigDigitMul(var res : BigNum; d : Integer);
var
  i : Longint;
  tmp, carry : Longint;
begin
  carry := 0;
  for i := 0 to MAXNUMLEN-1 do begin
    tmp := Longint(res[i])*d+carry;
    res[i] := tmp and 255;
    carry := tmp shr 8;
  end;
end;

procedure BigMul(var a : BigNum; b : Longint);
var
  res, add : BigNum;
  i : Integer;
begin
  BigInit(res);
  for i := 0 to 3 do begin
    if (b and 255) > 0 then begin
      BigShl(a, add, i);
      BigDigitMul(add, b and 255);
      BigAdd(res, add);
    end;
    b := b shr 8;
  end;
  BigMove(res, a);
end;

function NumLen(var a: BigNum) : Longint;
var
  i : Longint;
begin
  i := MAXNUMLEN-1;
  while (i >= 0) and (a[i] = 0) do
    Dec(i);
  NumLen := i;
end;

function BigSmallComp(var a : BigNum; b : Longint) : Integer;
var
  i : LongInt;
  t : LongWord;
begin
  i := NumLen(a);
  if i > 3 then
    BigSmallComp := 1
  else begin
    t := a[0]+a[1]*256+a[2]*65536+a[3]*65536*256;
    if t > b then
      BigSmallComp := 1
    else if t = b then
      BigSmallComp := 0
    else
      BigSmallComp := -1;
  end;
end;

function BigCompS(var a,b : BigNum; shift : Longint) : Integer;
var
  i : Longint;
begin
  i := MAXNUMLEN-1-shift;
  while (i >= 0) and (a[i+shift] = b[i]) do
    Dec(i);
  if i < 0 then begin
    i := shift-1;
    while (i >= 0) and (a[i] = 0) do
      Dec(i);
    if i < 0 then
      BigCompS := 0
    else
      BigCompS := 1;
  end
  else if a[i+shift] < b[i] then
    BigCompS := -1
  else
    BigCompS := 1;
end;

procedure BigSmallDiv(var a : BigNum; d : LongWord; var m : LongWord);
var
  mul, top : LongWord;
  i, j, k : Longint;
  res, sub, sub1 : BigNum;
begin
  i := NumLen(a);
  if i < 4 then begin
    top := ((LongWord(a[3])*256+LongWord(a[2]))*256+LongWord(a[1]))*256+LongWord(a[0]);
    m := top mod d;
    top := top div d;
    for i := 0 to 3 do begin
      a[i] := top and 255;
      top := top shr 8;
    end;
    Exit;
  end;

  BigInit(res);
  j := 3;
  while (j > 0) and ((d shr (8*j)) = 0) do
    Dec(j);
  i := i + (3-j);
  while i >= 3 do begin
    top := ((LongWord(a[i])*256+LongWord(a[i-1]))*256+LongWord(a[i-2]))*256+LongWord(a[i-3]);
    res[i-3+j] := top div d;
    BigInit(sub);
    sub[0] := res[i-3+j];
    BigMul(sub, d);
    BigShl(sub, sub1, i-3+j);
    BigSub(a, sub1);
    Dec(i);
  end;
  m := ((LongWord(a[3])*256+LongWord(a[2]))*256+LongWord(a[1]))*256+LongWord(a[0]) mod d;
  BigMove(res, a);
end;

procedure BigDiv(var a, d, m : BigNum);
var
  i, at, dt, shift : Longint;
  res, add, oldadd : BigNum;
  shiftedd : Array[0..7] of BigNum;
begin
  BigInit(res);
  at := NumLen(a);
  dt := NumLen(d);
  shift := at-dt;
  BigMove(d, shiftedd[0]);
  for i := 1 to 7 do
    BigBitShl(shiftedd[i-1], shiftedd[i]);
  while shift >= 0 do begin
    BigInit(add);
    res[shift] := 0;
    for i := 7 downto 0 do begin
      BigMove(add, oldadd);
      BigAdd(add, shiftedd[i]);
      res[shift] := res[shift] + (1 shl i);
      if BigCompS(a, add, shift) < 0 then begin
	res[shift] := res[shift] - (1 shl i);
	BigMove(oldadd, add);
      end;
    end;
    BigShl(add, oldadd, shift);
    BigSub(a, oldadd);
    Dec(shift);
  end;
  BigMove(a, m);
  BigMove(res, a);
end;

function Min(a,b : Longint) : LongInt;
begin
  if a < b then
    Min := a
  else
    Min := b;
end;

procedure Comb(n, k : Longint; var res : BigNum);
var
  i,j : Longint;
  tmp : Longint;
  fac, m : BigNum;
begin
  if k > n-k then
    k := n-k;
  BigInit(res);
  res[0] := 1;
  j := 2;
  for i := n downto (n-k+1) do
    BigMul(res,i);
  BigInit(fac);
  fac[0] := 1;
  for i := 2 to k do
    BigMul(fac, i);
  BigDiv(res, fac, m);
end;

procedure PrintComb(n, k : Longint);
var
  res : BigNum;
  i : Longint;
  digit : Longword;
  pbuf : Array[1..8192] of Char;
  pbuflen : Integer;
begin
  Comb(n, k, res);
  pbuflen := 0;
  while BigSmallComp(res, 0) > 0 do begin
    BigSmallDiv(res, 10, digit);
    Inc(pbuflen);
    pbuf[pbuflen] := Chr(digit+Ord('0'));
  end;
  if (pbuflen > 1) or ((pbuflen = 1) and (pbuf[1] <> '1')) then
    Write('are ')
  else
    Write('is ');
  for i := pbuflen downto 1 do
    Write(pbuf[i]);
  if (pbuflen > 1) or ((pbuflen = 1) and (pbuf[1] <> '1')) then
    Write(' routes')
  else
    Write(' route');
end;

begin
  ReadLn(p1, p2);
  while (p1 <> 0) or (p2 <> 0) do begin
    get_coord(p1, c11, c12);
    get_coord(p2, c21, c22);
    cd1 := c11-c21;
    cd2 := c12-c22;
    cd3 := 0;
    if cd1 < 0 then begin
      cd1 := -cd1;
      cd2 := -cd2;
    end;
    if cd2 < 0 then begin
      tmp := Min(cd1, -cd2);
      cd1 := cd1 - tmp;
      cd2 := cd2 + tmp;
      cd3 := -tmp;
    end;
    cd1 := abs(cd1);
    cd2 := abs(cd2);
    cd3 := abs(cd3);
    if cd1 = 0 then
      cd1 := cd3
    else if cd2 = 0 then
      cd2 := cd3;
    Write('There ');
    PrintComb(cd1+cd2,cd1);
    WriteLn(' of the shortest length ', cd1+cd2,'.');
    ReadLn(p1, p2);
  end;
end.

